@@ -3,6 +3,7 @@ from DataStructure.CounterHashMap import CounterHashMap
 from NGram.NGramNode import NGramNode
 from NGram.SimpleSmoothing import SimpleSmoothing
 from NGram.TrainedSmoothing import TrainedSmoothing
+from NGram.MultipleFile import MultipleFile
 import math
 
 
@@ -60,6 +61,25 @@ class NGram:
             self.rootNode = NGramNode(True, inputFile)
             inputFile.close()
 
+    def initWithMultipleFile(self, *args):
+        multipleFile = MultipleFile(list(args))
+        line = multipleFile.readLine().strip()
+        items = line.split()
+        self.__N = int(items[0])
+        self.__lambda1 = float(items[1])
+        self.__lambda2 = float(items[2])
+        self.__probabilityOfUnseen = self.__N * [0.0]
+        self.__interpolated = False
+        line = multipleFile.readLine().strip()
+        items = line.split()
+        for i in range(len(items)):
+            self.__probabilityOfUnseen[i] = float(items[i])
+        self.__vocabulary = set()
+        vocabularySize = int(multipleFile.readLine().strip())
+        for i in range(vocabularySize):
+            self.__vocabulary.add(multipleFile.readLine().strip())
+        self.rootNode = NGramNode(True, multipleFile)
+
     def getN(self) -> int:
         """
         RETURNS
@@ -527,6 +547,10 @@ class NGram:
         self.rootNode.setAdjustedProbability(countsOfCounts, height, self.vocabularySize() + 1, pZero)
         self.__probabilityOfUnseen[height - 1] = 1.0 / (self.vocabularySize() + 1)
 
+    def prune(self, threshold: float):
+        if threshold > 0.0 and threshold <= 1.0:
+            self.rootNode.prune(threshold, self.__N - 1)
+
     def saveAsText(self, fileName: str):
         """
         Save this NGram to a text file.
